@@ -65,7 +65,7 @@ except NameError:
     unicode = str
 
 
-__version__ = "2.0.1"
+__version__ = "2.0.2"
 
 
 class MyRequestHandler(BaseHTTPServer.BaseHTTPRequestHandler):
@@ -107,6 +107,9 @@ class MyRequestHandler(BaseHTTPServer.BaseHTTPRequestHandler):
                 pathname = self.translate_path(pathname)
             old_mtime = int(query['mtime'][0])
             return self.handle_polling(pathname, old_mtime)
+        elif self.path == '/favicon.ico':
+            return self.handle_image(self.server.renderer.favicon_path,
+                                     'image/x-icon')
         elif self.path.endswith('.gif'):
             return self.handle_image(self.translate_path(), 'image/gif')
         elif self.path.endswith('.png'):
@@ -121,7 +124,14 @@ class MyRequestHandler(BaseHTTPServer.BaseHTTPRequestHandler):
     def handle_polling(self, path, old_mtime):
         # TODO: use inotify if available
         while True:
-            mtime = int(os.stat(path).st_mtime)
+            try:
+                mtime = int(os.stat(path).st_mtime)
+            except OSError:
+                # Sometimes when you save a file in a text editor it stops
+                # existing for a brief moment.
+                # See https://github.com/mgedmin/restview/issues/11
+                time.sleep(0.1)
+                continue
             # we lose precision by using int(), but I'm nervous of
             # round-tripping floating point numbers through HTML and
             # comparing them for equality
@@ -326,12 +336,15 @@ class RestViewer(object):
 
     local_address = ('localhost', 0)
 
-    # only set one of those
+    # only set one of these two:
     css_url = None
     css_path = os.path.join(os.path.dirname(os.path.realpath(__file__)),
                             'default.css')
 
-    strict = None
+    favicon_path = os.path.join(os.path.dirname(os.path.realpath(__file__)),
+                                'favicon.ico')
+
+    strict = False
 
     def __init__(self, root, command=None):
         self.root = root
